@@ -1,24 +1,28 @@
 package Sort::Sub::pod_section_ala_perlancar;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-04-11'; # DATE
+our $DATE = '2021-04-23'; # DATE
 our $DIST = 'Sort-SubBundle-PERLANCAR'; # DIST
-our $VERSION = '0.084'; # VERSION
+our $VERSION = '0.085'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 
 our $SORT_SPEC = [
+    # ORIGINAL XXX are for forked modules, where the ORIGINAL XXX sections are
+    # the sections from the original (forked) module, and the XXX sections are
+    # for the new module (the fork).
+
     # preamble
     'NAME',
     'SPECIFICATION VERSION',
     'VERSION',
     'DEPRECATION NOTICE',
-    'SYNOPSIS',
+    'SYNOPSIS', 'ORIGINAL SYNOPSIS',
 
     # main content
-    'DESCRIPTION',
+    'DESCRIPTION', 'ORIGINAL DESCRIPTION',
 
     # Acme::CPANModules::*
     "ACME::CPANMODULES ENTRIES",
@@ -46,8 +50,8 @@ our $SORT_SPEC = [
     'COMPLETION',
 
     # FAQ (after all content & references)
-    'FAQ',
-    'FAQS',
+    'FAQ', 'ORIGINAL FAQ',
+    'FAQS', 'ORIGINAL FAQS',
 
     # links/pointers (CLI)
     'CONFIGURATION FILE',
@@ -57,24 +61,27 @@ our $SORT_SPEC = [
     'FILES',
 
     # todos
-    'TODO',
-    'TODOS',
+    'TODO', 'ORIGINAL TODO',
+    'TODOS', 'ORIGINAL TODOS',
 
     # links/pointers/extra information
-    'HISTORY',
-    'HOMEPAGE',
-    'SOURCE',
+    'HISTORY', 'ORIGINAL HISTORY',
+    'HOMEPAGE', 'ORIGINAL HOMEPAGE',
+    'SOURCE', 'ORIGINAL SOURCE',
+    'BUGS', 'ORIGINAL BUGS',
     qr/^.+'S BUGS$/i, # in a forked module, i put the original module's BUGS in ORIGMODULE'S BUGS
-    'BUGS',
-    'GOTCHAS', 'CAVEATS',
-    'SEE ALSO',
+    'GOTCHAS',
+    'CAVEATS',
+    'SEE ALSO', 'ORIGINAL SEE ALSO',
 
     # author & copyright
-    qr/^.+'S AUTHORS?$/i, # in a forked module, i put the original module's AUTHOR in ORIGMODULE'S AUTHOR
     qr/^AUTHORS?/,
+    qr/^.+'S AUTHORS?$/i, # in a forked module, i put the original module's AUTHOR in ORIGMODULE'S AUTHOR
+    qr/^ORIGINAL AUTHORS?/,
+
+    'COPYRIGHT AND LICENSE', 'ORIGINAL COPYRIGHT AND LICENSE',
+    'COPYRIGHT', 'ORIGINAL COPYRIGHT',
     qr/^.+'S COPYRIGHT( AND LICENSE)?$/i, # in a forked module, i put the original module's COPYRIGHT in ORIGMODULE'S COPYRIGHT
-    'COPYRIGHT AND LICENSE',
-    'COPYRIGHT',
 ];
 
 sub meta {
@@ -110,7 +117,7 @@ Sort::Sub::pod_section_ala_perlancar - Sort POD sections (headings) PERLANCAR-st
 
 =head1 VERSION
 
-This document describes version 0.084 of Sort::Sub::pod_section_ala_perlancar (from Perl distribution Sort-SubBundle-PERLANCAR), released on 2021-04-11.
+This document describes version 0.085 of Sort::Sub::pod_section_ala_perlancar (from Perl distribution Sort-SubBundle-PERLANCAR), released on 2021-04-23.
 
 =head1 SYNOPSIS
 
@@ -163,7 +170,7 @@ Source repository is at L<https://github.com/perlancar/perl-Sort-SubBundle-PERLA
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sort-SubBundle-PERLANCAR>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Sort-SubBundle-PERLANCAR/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -183,7 +190,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020, 2019, 2017, 2016 by perlancar@cpan.org.
+This software is copyright (c) 2021 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
